# Generated by roxygen2: do not edit by hand

S3method(autoplot,ba_analysis)
S3method(autoplot,deming_regression)
S3method(autoplot,pb_regression)
S3method(autoplot,precision_profile)
S3method(autoplot,precision_study)
S3method(plot,ba_analysis)
S3method(plot,deming_regression)
S3method(plot,pb_regression)
S3method(plot,precision_profile)
S3method(plot,precision_study)
S3method(print,ate_assessment)
S3method(print,ate_specs)
S3method(print,ba_analysis)
S3method(print,deming_regression)
S3method(print,pb_regression)
S3method(print,precision_profile)
S3method(print,precision_study)
S3method(print,sigma_metric)
S3method(print,summary.ba_analysis)
S3method(print,summary.precision_profile)
S3method(print,summary.precision_study)
S3method(print,summary.verify_precision)
S3method(print,verify_precision)
S3method(summary,ate_assessment)
S3method(summary,ate_specs)
S3method(summary,ba_analysis)
S3method(summary,deming_regression)
S3method(summary,pb_regression)
S3method(summary,precision_profile)
S3method(summary,precision_study)
S3method(summary,sigma_metric)
S3method(summary,verify_precision)
export(ate_assessment)
export(ate_from_bv)
export(autoplot)
export(ba_analysis)
export(deming_regression)
export(pb_regression)
export(precision_profile)
export(precision_study)
export(sigma_metric)
export(verify_precision)
importFrom(ggplot2,.data)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,annotation_logticks)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_errorbarh)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_log10)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(stats,aggregate)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,nls)
importFrom(stats,nls.control)
importFrom(stats,pnorm)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,var)
importFrom(utils,modifyList)
